@@ -9,7 +9,6 @@ This module implements differential operators on spherical grids
    make_divergence
    make_vector_gradient
    make_tensor_divergence
-   make_operator
    
    
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
@@ -53,8 +52,8 @@ def make_laplace(bcs: Boundaries, conservative: bool = True) -> Callable:
     r_min, r_max = bcs.grid.axes_bounds[0]
 
     # prepare boundary values
-    value_lower_bc = bcs[0].low.get_virtual_point_evaluator()
-    value_upper_bc = bcs[0].high.get_virtual_point_evaluator()
+    value_lower_bc = bcs[0].low.make_virtual_point_evaluator()
+    value_upper_bc = bcs[0].high.make_virtual_point_evaluator()
     
     if conservative:
         # create a conservative spherical laplace operator
@@ -182,8 +181,8 @@ def make_gradient(bcs: Boundaries) -> Callable:
     
     # prepare boundary values
     boundary = bcs[0]
-    value_lower_bc = boundary.low.get_virtual_point_evaluator()
-    value_upper_bc = boundary.high.get_virtual_point_evaluator()
+    value_lower_bc = boundary.low.make_virtual_point_evaluator()
+    value_upper_bc = boundary.high.make_virtual_point_evaluator()
     
     @jit_allocate_out(out_shape=(3, dim_r))
     def gradient(arr, out=None):
@@ -238,8 +237,8 @@ def make_divergence(bcs: Boundaries) -> Callable:
     
     # prepare boundary values
     boundary = bcs[0]
-    value_lower_bc = boundary.low.get_virtual_point_evaluator()
-    value_upper_bc = boundary.high.get_virtual_point_evaluator()
+    value_lower_bc = boundary.low.make_virtual_point_evaluator()
+    value_upper_bc = boundary.high.make_virtual_point_evaluator()
 
     if r_min == 0:
         @jit_allocate_out(out_shape=(dim_r,))
@@ -428,47 +427,16 @@ def make_poisson_solver(bcs: Boundaries, method: str = 'auto') -> Callable:
     return make_general_poisson_solver(matrix, vector, method)
 
 
-
-@fill_in_docstring
-def make_operator(op: str, bcs: Boundaries) -> Callable:
-    """ make a discretized operator for a spherical grid
-    
-    {DESCR_SPHERICAL_GRID}
-
-    Args:
-        op (str): Identifier for the operator. Some examples are 'laplace',
-            'gradient', or 'divergence'.
-        bcs (:class:`~pde.grids.boundaries.axes.Boundaries`):
-            {ARG_BOUNDARIES_INSTANCE}
-        
-    Returns:
-        A function that takes the discretized data as an input and returns
-        the data to which the operator `op` has been applied. This function
-        optionally supports a second argument, which provides allocated
-        memory for the output.
-    """
-    if op == 'laplace' or op == 'laplacian':
-        return make_laplace(bcs)
-    elif op == 'gradient':
-        return make_gradient(bcs)
-    elif op == 'divergence':
-        return make_divergence(bcs)
-    elif op == 'vector_gradient':
-        return make_vector_gradient(bcs)
-    elif op == 'tensor_divergence':
-        return make_tensor_divergence(bcs)
-    elif op == 'poisson_solver' or op == 'solve_poisson' or op == 'poisson':
-        return make_general_poisson_solver(*_get_laplace_matrix(bcs))
-    else:
-        raise NotImplementedError(f'Operator `{op}` is not defined for '
-                                  'spherical grids')
-        
-
 # register all operators with the grid class
-SphericalGrid.register_operator('laplace', make_laplace)
-SphericalGrid.register_operator('gradient', make_gradient)
-SphericalGrid.register_operator('divergence', make_divergence)
-SphericalGrid.register_operator('vector_gradient', make_vector_gradient)
-SphericalGrid.register_operator('tensor_divergence', make_tensor_divergence)
-SphericalGrid.register_operator('poisson_solver', make_poisson_solver)
-
+SphericalGrid.register_operator('laplace', make_laplace,
+                                rank_in=0, rank_out=0)
+SphericalGrid.register_operator('gradient', make_gradient,
+                                rank_in=0, rank_out=1)
+SphericalGrid.register_operator('divergence', make_divergence,
+                                rank_in=1, rank_out=0)
+SphericalGrid.register_operator('vector_gradient', make_vector_gradient,
+                                rank_in=1, rank_out=2)
+SphericalGrid.register_operator('tensor_divergence', make_tensor_divergence,
+                                rank_in=2, rank_out=1)
+SphericalGrid.register_operator('poisson_solver', make_poisson_solver,
+                                rank_in=0, rank_out=0)
